@@ -9,7 +9,7 @@ use locale;
 
 sub dispatch
 {
-    my( $self, $arg1, $arg2) = @_;
+    my( $self, $arg1, $arg2, $context) = @_;
     my ($arg1_type, $arg2_type) = (ref $arg1, ref $arg2);
     my $result = 0;
 
@@ -32,10 +32,25 @@ sub dispatch
     {
         $result = ($arg1->compare($arg2) > 0);
     }
-    else
+    elsif(
+        defined $arg1
+        and defined $arg2
+    )
     {
         $result = ($arg1 gt $arg2);
     }
+    else
+    {
+        die $self->get_render_error(
+            $context,
+            sprintf("don't know how to compare %s (%s) to %s (%s)"
+                , $arg1 // 'undef'
+                , $arg1_type || 'SCALAR'
+                , $arg2 // 'undef'
+                , $arg2_type || 'SCALAR'
+            )
+        );
+    }    
 
     return $result;
 }
