@@ -8,7 +8,7 @@ use DTL::Fast::Expression::Operator::Binary::Eq;
 
 sub dispatch
 {
-    my( $self, $arg1, $arg2) = @_;
+    my( $self, $arg1, $arg2, $context) = @_;
     my ($arg1_type, $arg2_type) = (ref $arg1, ref $arg2);
     my $result = undef;
 
@@ -94,11 +94,14 @@ sub dispatch
     # still nothing
     if( not defined $result )
     {
-        die sprintf("Don't know how to check that %s (%s) is in %s (%s)"
-            , $arg1 // 'undef'
-            , $arg1_type // 'undef'
-            , $arg2 // 'undef'
-            , $arg2_type // 'undef'
+        die $self->get_render_error(
+            $context,
+            sprintf("Don't know how to check that %s (%s) is in %s (%s)"
+                , $arg1 // 'undef'
+                , $arg1_type || 'SCALAR'
+                , $arg2 // 'undef'
+                , $arg2_type || 'SCALAR'
+            )
         );
     }
 
