@@ -8,7 +8,7 @@ use Scalar::Util qw(looks_like_number);
 
 sub dispatch
 {
-    my( $self, $arg1, $arg2) = @_;
+    my( $self, $arg1, $arg2, $context) = @_;
     my ($arg1_type, $arg2_type) = (ref $arg1, ref $arg2);
     my $result = 0;
 
@@ -20,13 +20,24 @@ sub dispatch
     {
         $result = $arg1->mul($arg2);
     }
-    elsif( $arg2 =~ /^\d+$/)
+    elsif(
+        defined $arg2
+        and defined $arg1
+        and $arg2 =~ /^\d+$/)
     {
         $result = "$arg1" x $arg2;
     }
     else
     {
-        die "Don't know how to multiplicate $arg1 ($arg1_type) to $arg2 ($arg2_type)";
+        die $self->get_render_error(
+            $context,
+            sprintf("don't know how to multiplicate %s (%s) to %s (%s)"
+                , $arg1 // 'undef'
+                , $arg1_type || 'SCALAR'
+                , $arg2 // 'undef'
+                , $arg2_type || 'SCALAR'
+            )
+        );
     }
 
     return $result;
