@@ -2,7 +2,7 @@ package DTL::Fast::Expression::Operator::Binary::NotIn;
 use strict; use utf8; use warnings FATAL => 'all'; 
 use parent 'DTL::Fast::Expression::Operator::Binary::In';
 
-$DTL::Fast::Expression::Operator::KNOWN{'not in'} = __PACKAGE__;
+$DTL::Fast::OPS_HANDLERS{'not in'} = __PACKAGE__;
 
 sub render
 {
