@@ -2,7 +2,7 @@ package DTL::Fast::Expression::Operator::Binary::Plus;
 use strict; use utf8; use warnings FATAL => 'all';
 use parent 'DTL::Fast::Expression::Operator::Binary';
 
-$DTL::Fast::Expression::Operator::KNOWN{'+'} = __PACKAGE__;
+$DTL::Fast::OPS_HANDLERS{'+'} = __PACKAGE__;
 
 use Scalar::Util qw(looks_like_number);
 
@@ -50,17 +50,38 @@ sub dispatch
         }
         else
         {
-            die "Don't know how to add $arg2 ($arg2_type) to a HASH";
+            die $self->get_render_error(
+                $context,
+                sprintf("don't know how to add %s (%s) to a HASH"
+                    , $arg2 // 'undef'
+                    , $arg2_type || 'SCALAR'
+                )
+            );
         }
     }
     elsif( UNIVERSAL::can($arg1, 'plus'))
     {
         return $arg1->plus($arg2, $context);
     }
-    else
+    elsif(
+        defined $arg1
+        and defined $arg2
+    )
     {
         return $arg1.$arg2;
     }
+    else
+    {
+        die $self->get_render_error(
+            $context,
+            sprintf("don't know how to add %s (%s) to %s (%s)"
+                , $arg1 // 'undef'
+                , $arg1_type || 'SCALAR'
+                , $arg2 // 'undef'
+                , $arg2_type || 'SCALAR'
+            )
+        );
+    }
 }
 
 1;
