@@ -1,20 +1,15 @@
 package DTL::Fast::Expression::Operator::Unary;
 use strict; use utf8; use warnings FATAL => 'all'; 
+use parent 'DTL::Fast::Entity';
 
-use DTL::Fast::Expression::Operator::Unary::Not;
-
-# not in Django
-use DTL::Fast::Expression::Operator::Unary::Defined;
+use DTL::Fast::Template;
 
 sub new
 {
     my( $proto, $argument, %kwargs ) = @_;
     $kwargs{'a'} = $argument;
-    $kwargs{'_template'}->{'modules'}->{$proto} //= $proto->VERSION // $DTL::Fast::VERSION;
-
-    delete $kwargs{'_template'};
     
-    return bless {%kwargs}, $proto;
+    return $proto->SUPER::new(%kwargs);
 }
 
 sub render
@@ -30,6 +25,6 @@ sub render
 sub dispatch
 {
     my( $self, $arg1 ) = @_;
-    die 'ABSTRACT: This method should be overriden in subclasses';
+    die 'Abstract method dispatch was not overriden in subclass '.(ref $self);
 }
 1;
\ No newline at end of file
