@@ -18,10 +18,10 @@ sub filter
     }
     else
     {
-        $value = length $value;
+        $value = length( $value // '' );
     }
     
     return $value;
 }
 
-1;
\ No newline at end of file
+1;
