@@ -8,7 +8,7 @@ $DTL::Fast::FILTER_HANDLERS{'wordwrap'} = __PACKAGE__;
 sub parse_parameters
 {
     my $self = shift;
-    die "No wrapping width specified"
+    die $self->get_parse_error("no wrapping width specified")
         if not scalar @{$self->{'parameter'}};
     $self->{'maxwidth'} = $self->{'parameter'}->[0];
     return $self;
@@ -18,10 +18,7 @@ sub parse_parameters
 #@Override
 sub filter
 {
-    my $self = shift;  # self
-    shift;  # filter_manager
-    my $value = shift;
-    my $context = shift;  # context
+    my($self, $filter_manager, $value, $context ) = @_;
 
     my $maxwidth = $self->{'maxwidth'}->render($context);
     my @value = split /\s+/s, $value;
