@@ -32,21 +32,23 @@ sub add_chunk
 #@Override
 sub parse_tag_chunk
 {
-    my( $self, $tag_name, $tag_param ) = @_;
+    my( $self, $tag_name, $tag_param, $chunk_lines ) = @_;
     
     my $result = undef;
 
     if( $tag_name eq 'elif' or $tag_name eq 'elsif' )
     {
         $self->add_condition($tag_param);
+        $DTL::Fast::Template::CURRENT_TEMPLATE_LINE += $chunk_lines;
     }
     elsif( $tag_name eq 'else' )
     {
         $self->add_condition(1);
+        $DTL::Fast::Template::CURRENT_TEMPLATE_LINE += $chunk_lines;
     }
     else
     {
-        $result = $self->SUPER::parse_tag_chunk($tag_name, $tag_param);
+        $result = $self->SUPER::parse_tag_chunk($tag_name, $tag_param, $chunk_lines);
     }
     
     return $result;
@@ -73,7 +75,7 @@ sub render
 sub add_condition
 {
     my( $self, $condition ) = @_;
-    push @{$self->{'conditions'}}, DTL::Fast::Tag::If::Condition->new($condition, '_template' => $self->{'_template'});
+    push @{$self->{'conditions'}}, DTL::Fast::Tag::If::Condition->new($condition);
     return $self;
 }
 
